summaryrefslogtreecommitdiffstats
path: root/katomic/feld.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'katomic/feld.cpp')
-rw-r--r--katomic/feld.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/katomic/feld.cpp b/katomic/feld.cpp
index e01060cb..48150efd 100644
--- a/katomic/feld.cpp
+++ b/katomic/feld.cpp
@@ -1,15 +1,15 @@
/****************************************************************
**
** Implementation Feld class, derieved from Qt tutorial 8
**
****************************************************************/
// bemerkungen : wenn paintEvent aufgerufen wird, wird das komplette
-// widget gelöscht und nur die sachen gezeichnet, die in
+// widget gel�scht und nur die sachen gezeichnet, die in
// paintEvent stehen ! sollen dinge z.b nur bei maustasten-
-// druck gezeichnet werden, so muß dies in mousePressEvent
+// druck gezeichnet werden, so mu� dies in mousePressEvent
// stehen !
-// paintEvent wird aufgerufen, falls fenster überdeckt wird,
+// paintEvent wird aufgerufen, falls fenster �berdeckt wird,
// oder auch einfach bewegt wird
#include <kiconloader.h>
@@ -26,8 +26,8 @@
extern Options settings;
-Feld::Feld( TQWidget *parent, const char *name ) :
- TQWidget( parent, name ),
+Feld::Feld( TQWidget *tqparent, const char *name ) :
+ TQWidget( tqparent, name ),
data(locate("appdata", "pics/abilder.png")),
undoBegin (0), undoSize (0), redoSize (0)
{
@@ -45,7 +45,7 @@ Feld::Feld( TQWidget *parent, const char *name ) :
setMouseTracking(true);
- setFocusPolicy(TQWidget::StrongFocus);
+ setFocusPolicy(TQ_StrongFocus);
setBackgroundColor( TQColor( 0, 0, 0) );
setFixedSize(15 * 30, 15 * 30);
@@ -70,7 +70,7 @@ void Feld::resetValidDirs()
void Feld::load (const KSimpleConfig& config)
{
if(moving)
- killTimers();
+ TQT_TQOBJECT(this)->killTimers();
mol->load(config);
@@ -124,7 +124,7 @@ void Feld::mousePressEvent (TQMouseEvent *e)
resetValidDirs();
chosen = false;
}
- emitStatus();
+ emittqStatus();
}
const atom& Feld::getAtom(uint index) const
@@ -154,7 +154,7 @@ void Feld::nextAtom()
xpos = x; ypos = y;
chosen = true;
resetValidDirs();
- emitStatus();
+ emittqStatus();
return;
}
}
@@ -187,7 +187,7 @@ void Feld::previousAtom()
xpos = x; ypos = y;
chosen = true;
resetValidDirs();
- emitStatus();
+ emittqStatus();
return;
}
}
@@ -198,7 +198,7 @@ void Feld::previousAtom()
}
-void Feld::emitStatus()
+void Feld::emittqStatus()
{
if (!chosen || moving) {}
else {
@@ -231,7 +231,7 @@ void Feld::done ()
if (moving)
return;
- emitStatus();
+ emittqStatus();
if (checkDone())
emit gameOver(moves);
@@ -492,7 +492,7 @@ void Feld::timerEvent (TQTimerEvent *)
if (frames <= 0)
{
moving = false;
- killTimers ();
+ TQT_TQOBJECT(this)->killTimers ();
done();
dir = None;
}
@@ -574,7 +574,7 @@ void Feld::paintEvent( TQPaintEvent * )
x = i * 30;
y = j * 30;
- // zeichnet Randstücke
+ // zeichnet Randst�cke
if (feld [i] [j] == 254) {
putNonAtom(i, j, Feld::None, true); continue;
}
@@ -628,7 +628,7 @@ void Feld::paintEvent( TQPaintEvent * )
}
- // zeichnet Verbindungsstäbe
+ // zeichnet Verbindungsst�be
if (getAtom(feld [i] [j]).obj >= 'A' &&
getAtom(feld [i] [j]).obj <= 'F')
bitBlt (this, x, y,
@@ -1,15 +1,15 @@
/****************************************************************
**
-** Implementation Feld class, derieved from Qt tutorial 8
+** Implementation Feld class, derieved from TQt tutorial 8
**
****************************************************************/